/*
 *  
 *  $Id: herramientadeshacer.h 4476 2011-12-13 08:23:27Z carlos $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#pragma once

#include <export/iherramientadeshacer.h>
#include <api/api.h>

#include <map>


namespace GNC {

	class EXTAPI HerramientaDeshacer : public GNC::GCS::IHerramientaDeshacer {

	protected:

	public:
		HerramientaDeshacer();
		~HerramientaDeshacer();
		//menu del reset
		virtual bool AppendInMenu(wxWindow* pParent, wxMenu* pMenuParent);

		//region "Realización de la interfaz IHerramienta"

		// Setup de paneles
		virtual void CrearPaneles( wxPanel* pParent );

		//endregion

		//deshacer
		virtual void Deshacer();
		//rehacer
		virtual void Rehacer();
		virtual bool PuedeDeshacer(std::string& nombreAccion);
		virtual bool PuedeRehacer(std::string& nombreAccion);

		virtual void ConectarContratoFalso(bool activar);
		virtual void SetVistaActiva(GNC::GCS::IVista* pVista);
		virtual void ConectarContratos(bool activar);


	protected:

	};
}
